// ==================================================================================
//
//	File Name:			SalesBillData.cs
//
//  Description:		The data structure of Sales bill data in format DataSet
//
//  Tables:				nothing
//
//  Author:				Ben
//
//  Create Date:		2005.2.28
//
// ==================================================================================
using System;
using System.Data;
using System.Runtime.Serialization;

namespace CU.Common.Data
{
	[System.ComponentModel.DesignerCategory("Code")]
	[SerializableAttribute] 
	public class SalesBillData : DataSet
	{
		
		// *****************************************************************
		//	Constants of master table of Sales Data
		//******************************************************************
		public const String SALESBILL_TABLE				= "SalesBillTable";
		
		public const String TrnDate_Field				= "TrnDate";

		public const String BILLNO_FIELD				= "BillNo";

		public const String CUSTOMERNO_FIELD			= "CustomerNo";

		public const String BILLSTATE_FIELD				= "BillState";


		// *****************************************************************
		//	Constants of child table of Sales Data
		//******************************************************************
		public const String SALESBILLCHILD_TABLE		= "SalesBillChildTable";

		public const String INVENTORYID_FIELD			= "InvtID";

		public const String INVENTORYNAME_FIELD			= "Descr";

		public const String QTY_FIELD					= "Qty";

		public const String PRICE_FIELD					= "Price";

		public const String SUBTOTAL_FIELD				= "SubTotal";

		public const String DELIVERYDATE_FIELD			= "DeliveryDate";

        
		private SalesBillData(SerializationInfo info, StreamingContext context) : base(info, context) 
		{		
		}		
        
		public SalesBillData()
		{
			//
			// Create the tables in the dataset
			//
			BuildDataTables();
		}
        
		//----------------------------------------------------------------
		//   Creates datatables
		//----------------------------------------------------------------
		private void BuildDataTables()
		{
			//
			// Create the Sales Bill master table
			//
			DataTable table   = new DataTable(SALESBILL_TABLE);
			DataColumnCollection columns = table.Columns;
            
			columns.Add(TrnDate_Field, typeof(System.DateTime));
			columns.Add(BILLNO_FIELD, typeof(System.String));
			columns.Add(CUSTOMERNO_FIELD, typeof(System.String));
			columns.Add(BILLSTATE_FIELD, typeof(System.Int32));

			this.Tables.Add(table);

			//
			// Create the Sales Bill child table
			//
			DataTable ctable   = new DataTable(SALESBILLCHILD_TABLE);
			DataColumnCollection ccolumns = ctable.Columns;
            
			ccolumns.Add(BILLNO_FIELD, typeof(System.String));
			ccolumns.Add(INVENTORYID_FIELD, typeof(System.String));
			ccolumns.Add(INVENTORYNAME_FIELD, typeof(System.String));
			ccolumns.Add(QTY_FIELD, typeof(System.Double));
			ccolumns.Add(PRICE_FIELD, typeof(System.Double));
			ccolumns.Add(SUBTOTAL_FIELD, typeof(System.Double));
			ccolumns.Add(DELIVERYDATE_FIELD, typeof(System.DateTime));

			this.Tables.Add(ctable);

			//
			// Create the data relation between master table and child table.
			//
			DataRelation dr = new DataRelation("SalesData",this.Tables[SALESBILL_TABLE].Columns[BILLNO_FIELD],this.Tables[SALESBILLCHILD_TABLE].Columns[BILLNO_FIELD]);
			this.Relations.Add(dr);
		}
        
	} //class SalesBillData
}
